import objectdraw.*;

import java.awt.*;

public class ColoredSpotty extends FrameWindowController implements ClientListener {
	Client network;
	
	public void begin() {
		Network.configure("ColoredSpotty", new ColoredSpottyServer(), this);
	}
	
	public void onMousePress(Location point) {
		if(network != null) {
			network.sendMessage(Code.encodeLocation(point));
		}
	}
	
	public void makeSpot(FilledOval oval) {
		oval.addToCanvas(canvas);
		EventTimer timer = new EventTimer(this, "fade", oval, EventTimer.SELF);
		timer.start(3, .05);
	}
	
	public void fade(FilledOval oval, EventTimer timer) {
		Color c = oval.getColor();
		int alpha = c.getAlpha() - 5;
		
		if(alpha == 0) {
			oval.removeFromCanvas();
			timer.stop();
		} else {
			oval.setColor(new Color(c.getRed(), c.getGreen(), c.getBlue(), alpha));
		}
	}

	public void clientConnected(Client client) { 
		network = client;
	}
	
	public void clientDisconnected(Client client) { 
		network = null;
	}
	
	public void messageReceived(Client client, String message) {
		int pos = message.indexOf(";");
		Location point = Code.decodeLocation(message.substring(0, pos));
		int channel = Integer.parseInt(message.substring(pos + 1));
		
		Color color = Color.getHSBColor((.618034f * channel) % 1, 1f, 1f);
		makeSpot(new FilledOval(point, 20, 20, color, canvas));
	}

	public static void main(String[] args) {
		new ColoredSpotty();
	}
}
