import objectdraw.*;
import java.awt.*;

public class SnakesClient extends FrameWindowController implements ClientListener {
	Client network;
	SnakesServer server;
	
	private static final Color[] colors = {Color.RED, Color.BLUE, Color.GREEN, Color.YELLOW, Color.GRAY};
	
	public SnakesClient() {
		super(600, 600, "Snakes");
		canvas.setBackground(Color.BLACK);
		Network.configure("Snakes", server = new SnakesServer(), this);
	}
	
	public void onOtherPress(String key) {
		if(network != null) network.sendMessage(key + "Press");
	}
	
	public void onOtherRelease(String key) {
		if(network != null) network.sendMessage(key + "Release");
	}

	public void clientConnected(Client client) {
		network = client;
	}

	public void clientDisconnected(Client client) {
		network = null;
	}
	
	public void onEnterPress() {
		server.start();
	}
	
	public Location decodeLocation(String message) {
		int pos = message.indexOf(",");
		int x = Integer.parseInt(message.substring(0, pos));
		int y = Integer.parseInt(message.substring(pos + 1));
		return new Location(x * 6, y * 6);
	}
	
	public void decode(String message, Color color) {
		for(String segment : message.split(";")) {
			Location loc = decodeLocation(segment);
			new FilledRect(loc, 6, 6, color, canvas);
		}
	}

	public void messageReceived(Client client, String message) {
		canvas.clear();
		
		int i = 0;
		for(String part : message.split("\n")) {
			decode(part, colors[i++]);
		}
	}

	public static void main(String[] args) {
		new SnakesClient();
	}
}
