import java.util.Iterator;
import java.util.LinkedList;

import objectdraw.*;

public class SnakesServer implements ServerListener {
	LinkedList<Snake> snakes;
	LinkedList<Location> food;
	Server network;
	int foodTimer;
	EventTimer timer;
	
	public void update() {
		for(Snake snake : snakes) {
			snake.update(this);
		}
		
		while(foodTimer == 0) {
			Location loc = new Location((int)(Math.random() * 100), (int)(Math.random() * 100));
			if(!hitSnakeOrWall(loc) && !hitFood(loc, false)) {
				foodTimer = 20;
				food.addLast(loc);
			}
		}
		foodTimer = foodTimer - 1;
		
		network.sendMessage(encode());
	}
	
	public String encode() {
		String message = "";
		for(Snake snake : snakes) {
			message += snake.encode() + "\n";
		}
		
		for(Location f : food) {
			message += Code.encodeLocation(f) + ";";
		}
		
		return message;
	}
	
	public void channelClosed(Server server, int channelID, String channelName) { }

	public void channelOpened(Server server, int channelID, String channelName) { 
		if(!timer.isRunning()) network.sendMessage(encode(), channelID);
	}

	public void messageReceived(Server server, int channelID, String channelName, String message) {
		if(channelID >= snakes.size()) return;
		
		Snake snake = snakes.get(channelID);
		
		if(message.equals("leftPress")) snake.turnLeft();
		else if(message.equals("rightPress")) snake.turnRight();
	}
	
	public void start() {
		if(network != null && !timer.isRunning()) timer.start(.1, .1);
	}

	public void serverStarted(Server server) {
		snakes = new LinkedList<Snake>();
		food = new LinkedList<Location>();
		network = server;
		foodTimer = 0;
		
		snakes.add(new Snake(10, 10, 1, 0));
		snakes.add(new Snake(90, 10, 0, 1));
		snakes.add(new Snake(90, 90, -1, 0));
		snakes.add(new Snake(10, 90, 0, -1));
		
		timer = new EventTimer(this, "update");
	}

	public void serverStopped(Server server) { }
	
	public boolean hitSnakeOrWall(Location loc) {
		if(loc.getX() < 0 || loc.getX() >= 100 || loc.getY() < 0 || loc.getY() >= 100) return true;
		
		for(Snake snake : snakes) {
			if(snake.contains(loc)) return true;
		}
		return false;
	}
	
	public boolean hitFood(Location loc, boolean eatIt) {
		Location found = null;
		
		for(Location f : food) {
			if(f.getX() == loc.getX() && f.getY() == loc.getY()) {
				found = loc;
			}
		}
		
		if(found != null) {
			food.remove(found);
			return true;
		} else {
			return false;
		}
	}
}
