package objectdraw;

/**
 * <code>Drawable1DInterface</code> is the interface shared by all one dimensional
 * graphical objects - that is, <code>Line</code>s and <code>AngLine</code>s.
 * 
 * @author Russell Zahniser (russell@zahniser.net)
 *
 */
public interface Drawable1DInterface extends DrawableInterface {
	/**
	 * Get the location of the start of the line.
	 * @return the <code>Location</code> of the start of the line.
	 */
	public Location getStart();
	/**
	 * Get the location of the end of the line.
	 * @return the <code>Location</code> of the end of the line.
	 */
	public Location getEnd();
	/**
	 * Move the start of the line to a new location
	 * @param point <code>Location</code> to which the start of the line should be moved
	 */
	public void setStart(Location point);
	/**
	 * Move the start of the line to a new location
	 * @param x x coordinate to which the start of the line should be moved
	 * @param y y coordinate to which the start of the line should be moved
	 */
	public void setStart(double x, double y);
	/**
	 * Move the end of the line to a new location
	 * @param point <code>Location</code> to which the end of the line should be moved
	 */
	public void setEnd(Location point);
	/**
	 * Move the end of the line to a new location
	 * @param x x coordinate to which the end of the line should be moved
	 * @param y y coordinate to which the end of the line should be moved
	 */
	public void setEnd(double x, double y);
	/**
	 * Move both endpoints of the line.
	 * @param start <code>Location</code> to which the start of the line should be moved
	 * @param end <code>Location</code> to which the end of the line should be moved
	 */
	public void setEndPoints(Location start, Location end);
	/**
	 * Move both endpoints of the line.
	 * @param x1 x1 coordinate to which the start of the line should be moved
	 * @param y1 y1 coordinate to which the start of the line should be moved
	 * @param x2 x coordinate to which the end of the line should be moved
	 * @param y2 y coordinate to which the end of the line should be moved
	 */
	public void setEndPoints(double x1, double y1, double x2, double y2);
}
