package objectdraw;

import java.awt.geom.Rectangle2D;

/**
 * <code>Drawable2DInterface</code> is the interface shared by all two dimensional
 * graphical objects - rectangles, ovals, arcs, and text.
 * 
 * @author Russell Zahniser (russell@zahniser.net)
 *
 */
public interface Drawable2DInterface extends LocatableInterface {
	/**
	 * Return the height of the rectangle bounding this object.
	 * @return the height of the rectangle bounding this object.
	 */
	public int getWidth();
	/**
	 * Return the width of the rectangle bounding this object.
	 * @return the width of the rectangle bounding this object.
	 */
	public int getHeight();
	/**
	 * Return the height of the rectangle bounding this object, in double precision.
	 * @return the height of the rectangle bounding this object, in double precision.
	 */
	public double getDoubleWidth();
	/**
	 * Return the height of the rectangle bounding this object, in double precision.
	 * @return the height of the rectangle bounding this object, in double precision.
	 */
	public double getDoubleHeight();
	/**
	 * Return <code>true</code> if the rectangle bounding this object overlaps with the
	 * rectangle bounding another object; <code> false</code> otherwise.
	 * @param other another two dimensional object to check for overlapping with
	 * @return whether the bounding rectangles of the two objects overlap
	 */
	public boolean overlaps(Drawable2DInterface other);
	/**
	 * @deprecated for internal use only
	 */
	public Rectangle2D getBounds();
}
