package objectdraw;

import java.util.ArrayList;

/**
 * A <code>DrawableIterator</code> is a list of <code>DrawableInterface</code> objects that
 * you can read through one by one in order. It is used to report a list of objects on
 * a canvas. The typical usage looks like this:
 * <br><br><code>
 * DrawableIterator iter = canvas.getDrawableIterator();<br>
 * while(iter.hasNext()) {<br>
 * &nbsp;&nbsp;&nbsp;DrawableInterface d = iter.next();<br>
 * &nbsp;&nbsp;&nbsp;// do something with d<br>
 * }<br>
 * </code>
 * @see DrawingCanvas#getDrawableIterator() DrawingCanvas.getDrawableIterator()
 * @author Russell Zahniser (russell@zahniser.net)
 */
public class DrawableIterator {
	private ArrayList list;
	private int index;
	
	protected DrawableIterator(ArrayList drawables) {
		if(drawables != null) list = new ArrayList(drawables);
	}
	
	/**
	 * Return <code>true</code> if there are more objects left to be read from this iterator, 
	 * <code>false</code> if it is at the end of its list.
	 * @return whether this iterator has more drawables remaining to be read
	 */
	public boolean hasNext() {
		return list != null && index < list.size();
	}
	
	/**
	 * Retrieve the next <code>DrawableInterface</code> object from this iterator.
	 * @return the next <code>DrawableInterface</code> object from this iterator.
	 * @throws <code>IndexOutOfBoundsException</code> if there are no more drawables to
	 * be retrieved.
	 */
	public DrawableInterface next() {
		if(!hasNext()) throw new IndexOutOfBoundsException("No more drawables in this iterator!");
		return (DrawableInterface)list.get(index++);
	}
}
