package objectdraw;

import java.awt.BasicStroke;

/**
 * <code>DrawableStrokeInterface</code> is the interface shared by all objects that consist of
 * lines, instead of filled in areas. It contains method to change the line width, or to change
 * the stroke of the line, giving it a different appearance at its corners and ends or causing
 * it to be drawn in a dashed pattern.
 * @author Russell Zahniser (russell@zahniser.net)
 */
public interface DrawableStrokeInterface {
	/**
	 * The default stroke with which lines will be drawn - width 1, round cap and joints.
	 */
	public static final BasicStroke DEFAULT_STROKE = new BasicStroke(2f, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND);
	/**
	 * The distance a point may be from a line to still be considered contained in it.
	 */
	public static final double CLICK_SIZE = 4;
	
	/**
	 * Return the width of this object's lines.
	 * @return the width of this object's lines
	 */
	public double getLineWidth();
	/**
	 * Set the width of this object's lines
	 * @param width the new width of this object's lines
	 */
	public void setLineWidth(double width);
	
	/**
	 * Return the stroke used for this object's lines.
	 * @return the stroke used for this object's lines
	 */
	public BasicStroke getStroke();
	/**
	 * Set the stroke used for this object's lines
	 * @param stroke the new stroke for this object's lines
	 */
	public void setStroke(BasicStroke stroke);
}
