package objectdraw;

import javax.swing.SwingUtilities;

/**
 * <code>FrameWindowController</code> is a <code>WindowController</code> that automatically 
 * pops up in its own frame (window) when it is constructed. This allows you, in a program like 
 * BlueJ or DrJava, to pop up a window instantly by creating an object, rather than having to 
 * create it and then tell it to <code>startController()</code>. In these programs, you should 
 * make your <code>WindowController</code> classes extend <code>FrameWindowController</code> 
 * instead.
 * 
 * @author Russell Zahniser (russell@zahniser.net)
 */
public class FrameWindowController extends WindowController {
	/**
	 * Construct a window controller of size 400 by 400, which will immediately appear in its 
	 * own window.
	 * @param name Name of window
	 */
	public FrameWindowController(String name) {
		this(400, 400, name);
	}
	
	/**
	 * Construct a window controller of the specified size, which will appear in its own window.
	 * @param width Width of the controller
	 * @param height Height of the controller
	 * @param name Name of window
	 */
	public FrameWindowController(int width, int height, String name) {
		final String windowName = name;
		final int w = width, h = height;
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				startController(w, h, windowName);
			}
		});
	}
	
	/**
	 * Construct a window controller of size 400 by 400, which will immediately appear in its 
	 * own window.
	 */
	public FrameWindowController() {
		this(400, 400, "ObjectDraw");
	}
	
	/**
	 * Construct a window controller of the specified size, which will appear in its own window.
	 * @param width Width of the controller
	 * @param height Height of the controller
	 */
	public FrameWindowController(int width, int height) {
		this(width, height, "ObjectDraw");
	}
}
