package objectdraw;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.geom.AffineTransform;
import java.awt.geom.Ellipse2D;
import java.awt.image.BufferedImage;

import javax.swing.JComponent;

/**
 * The actual implementation of DrawingCanvas.
 * @deprecated for internal use only
 * @author Russell Zahniser (russell@zahniser.net)
 *
 */
public class JDrawingCanvas extends JComponent implements DrawingCanvas {
	private boolean auto;
	private Location loupe = null;
	private double loupeSize = 30;
	private double loupeZoom = 3;
	private static int ID = 0;
	private int id;
	private BufferedImage buffer;
	private boolean needsRepainting = false;
	
	public JDrawingCanvas() {
		super();
		setOpaque(true);
		setBackground(Color.WHITE);
		setFocusTraversalKeysEnabled(false);
		setPreferredSize(new Dimension(400, 400));
		auto = true;
		id = ID++;
	}
	
	public void clear() {
		ObjectDrawShape.clearCanvas(this);
	}

	public void disableAutoRepaint() {
		auto = false;
	}

	public void enableAutoRepaint() {
		auto = true;
	}
	
	public void repaint() {
		needsRepainting = true;
		super.repaint();
	}

	public DrawableIterator getDrawableIterator() {
		return ObjectDrawShape.getDrawables(this);
	}

	public void update() {
		if(auto) {
			needsRepainting = true;
			repaint();
		}
	}
	
	private void createBuffer() {
		if(buffer != null && buffer.getWidth(null) == getWidth() && buffer.getHeight(null) == getHeight()) return;
		
		buffer = new BufferedImage(getWidth(), getHeight(), BufferedImage.TYPE_INT_RGB);
	}
	
	private void repaintBuffer() {
		if(!needsRepainting) return;
		
		createBuffer();
		Graphics2D g = (Graphics2D)buffer.createGraphics();
		
		ObjectDrawShape.draw(this, g);
		if(loupe != null) {
			Ellipse2D loupeArea = new Ellipse2D.Double(loupe.getDoubleX() - loupeZoom * loupeSize / 2,
					loupe.getDoubleY() - loupeZoom * loupeSize / 2, loupeZoom * loupeSize, loupeZoom * loupeSize);
			g.setColor(getBackground());
			g.fill(loupeArea);
			g.setStroke(new BasicStroke(4f));
			g.draw(loupeArea);
			g.setStroke(new BasicStroke(2f));
			g.setColor(new Color(0xFFFFFF - (0xFFFFFF & getBackground().getRGB())));
			g.draw(loupeArea);
			g.clip(loupeArea);
			
			AffineTransform t = AffineTransform.getTranslateInstance(loupe.getDoubleX(), loupe.getDoubleY());
			t.scale(loupeZoom, loupeZoom);
			t.translate(-loupe.getDoubleX(), -loupe.getDoubleY());
			
			g.transform(t);
			
			ObjectDrawShape.draw(this, g);
		}
		
		g.dispose();
		needsRepainting = false;
	}
	
	public void paintComponent(Graphics graphics) {
		repaintBuffer();
		graphics.drawImage(buffer, 0, 0, null);
	}

	public void clearLoupe() {
		loupe = null;
		repaint();
	}

	public void setLoupe(Location point, double size, double zoom) {
		loupe = new Location(point);
		loupeSize = size;
		loupeZoom = zoom;
		repaint();
	}

	public void setLoupe(Location point) {
		loupe = new Location(point);
		repaint();
	}
	
	public String toString() {
		if(id == 0) {
			return "canvas";
		} else {
			return "canvas" + id;
		}
	}
}
