package objectdraw;

/**
 * <code>LocatableInterface</code> is an interface shared by all objects except for
 * lines, containing the methods for retrieving the object's reference point. This point is
 * typically the top left of the object. For a <code>Turtle</code>, it is the current location
 * of the turtle, and for a <code>Text</code>, it is the location of the basis.
 * @author Russell Zahniser (russell@zahniser.net)
 */
public interface LocatableInterface extends DrawableInterface {
	/**
	 * Get this object's x coordinate.
	 * @return this object's x coordinate
	 */
	public int getX();
	/**
	 * Get this object's y coordinate.
	 * @return this object's y coordinate
	 */
	public int getY();
	/**
	 * Get this object's x coordinate, in double precision.
	 * @return this object's x coordinate, in double precision
	 */
	public double getDoubleX();
	/**
	 * Get this object's y coordinate, in double precision.
	 * @return this object's y coordinate, in double precision
	 */
	public double getDoubleY();
	/**
	 * Get this object's location.
	 * @return the <code>Location</code> of this object.
	 */
	public Location getLocation();
}
