package objectdraw;

import java.awt.Color;
import java.awt.geom.Rectangle2D;

/**
 * @deprecated for internal use only
 * ObjectDrawRectangularShape is the superclass of all the rectangle, arc, oval, and rounded rect
 * shapes. It is responsible for maintaining the information on the width and height of the shape,
 * and ensuring that width and height are never negative. So, subclasses need only write a
 * constructor that passes along the appropriate information to super(), a makeShape() method,
 * and code to deal with other information specific to them, such as arc angles and stroke.
 * @author Russell Zahniser (russell@zahniser.net)
 *
 */
public abstract class ObjectDrawRectangularShape extends ObjectDrawShape implements Drawable2DInterface, Resizable2DInterface {
	private double width, height;
	
	// RI:
	// Width and height are non-negative
	
	public ObjectDrawRectangularShape(double x, double y, double width, double height, boolean filled, Color c, DrawingCanvas canvas) {
		super(new Location((width < 0 ? x + width : x), (height < 0 ? y + height : y)), filled, c, canvas);
		
		getMyLocation().depend(this);
		
		this.width = Math.abs(width);
		this.height = Math.abs(height);
	}
	
	public boolean contains(Location point) {
		return getShape().contains(point.getDoubleX(), point.getDoubleY());
	}
	
	public Location getLocation() {
		return getMyLocation();
	}

	public int getHeight() {
		return (int)(height + .5);
	}
	
	public double getDoubleHeight() {
		return height;
	}

	public int getWidth() {
		return (int)(width + .5);
	}
	
	public double getDoubleWidth() {
		return width;
	}

	public int getX() {
		return getLocation().getX();
	}

	public int getY() {
		return getLocation().getY();
	}
	
	public double getDoubleX() {
		return getLocation().getDoubleX();
	}
	
	public double getDoubleY() {
		return getLocation().getDoubleY();
	}
	
	/**
	 * @deprecated for internal use only
	 */
	public Rectangle2D getBounds() {
		return getShape().getBounds2D();
	}

	public boolean overlaps(Drawable2DInterface other) {
		return getBounds().intersects(other.getBounds());
	}

	public void setHeight(double h) {
		setSize(width, h);
	}

	public void setSize(double w, double h) {
		width = w;
		height = h;
		update();
	}

	public void setWidth(double w) {
		setSize(w, height);
	}
	
	/**
	 * @deprecated for internal use only
	 */
	protected String toString(String middle) {
		return super.toString(Text.formatDecimal(getDoubleX()) + ", "
			+ Text.formatDecimal(getDoubleY()) + ", " + Text.formatDecimal(width) + ", "
			+ Text.formatDecimal(height) + middle);
	}
}
