package objectdraw;

/**
 * <code>Resizable2DInterface</code> is the interface shared by all two dimensional object that
 * can be resized. This includes all the rectangles, ovals, arcs, and rounded rectangles, but
 * not text or turtles.
 * 
 * @author Russell Zahniser (russell@zahniser.net)
 *
 */
public interface Resizable2DInterface extends DrawableInterface {
	/**
	 * Set the width and height of this object. Its upper left corner will stay fixed in place,
	 * and the opposite corner will move to make it the new size.
	 * @param width new width
	 * @param height new height
	 */
	public void setSize(double width, double height);
	/**
	 * Set the width of this object, leaving its left edge in place and stretching the right.
	 * @param w new width
	 */
	public void setWidth(double w);
	/**
	 * Set the height of this object, leaving its top edge in place and stretching the bottom.
	 * @param h new height
	 */
	public void setHeight(double h);
}
